from setuptools import setup, find_packages

setup(
    name='lynn_base',
    version='1.0.2',
    py_modules=['lynn_base'],
    author='lynn',
    author_email='yinyin2568@163.com',
    url='https://gitee.com/lynn2568',
    description='a simple object of 【json/yaml/excel/log/mysql/redis/ssh/mongodb】',
    classifiers=[
        # 'base_json :: Python'
    ],
    install_requires=[],
)